@@ -56,12 +56,6 @@ gtk_requisition_get_height(const GtkRequisition *req)
     return req->height;
 }
 
-const GtkAllocation*
-gtk_widget_get_allocation(const GtkWidget *wdg)
-{
-    return &wdg->allocation;
-}
-
 GtkAllocation*
 gtk_allocation_new(void)
 {
@@ -1537,6 +1531,12 @@ gtk_dialog_get_vbox(GtkDialog *dialog)
  * @widget_pointer: (inout) (transfer none):
  */
 
+/**
+ * gtk_widget_get_allocation:
+ * @widget: the widget
+ * @allocation: (out): location to store the allocation
+ */
+
 /**
  * gtk_widget_get_accessible:
  *
